==> haskell-pipes-http-1.0.6-735-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-K0EfiPAsFuqHRyZdvGokpb
key:                  pipes-http-1.0.6-K0EfiPAsFuqHRyZdvGokpb
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  739b576ab1b6b17fc3af8cdb81532b83
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-K0EfiPAsFuqHRyZdvGokpb
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http-client-0.7.19-LiXl0zXhncYKUDAcqgcwk8
    http-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
    pipes-4.3.16-9zHzb183F6A3JgmP3IBz5A

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.6-757-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-5BLF5VLRVLbCOcj1EKy4RI
key:                  pipes-http-1.0.6-5BLF5VLRVLbCOcj1EKy4RI
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  fd9c63f5bdcf7918e666d55fc12242a0
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-5BLF5VLRVLbCOcj1EKy4RI
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http-client-0.7.19-Iyp8kyAVyHs5ic3dfNFLTs
    http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
    pipes-4.3.16-LZfhFcVjMzIBhB4624UE5U

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
